@@ -14,8 +14,24 @@ def __check_os__(supported=[]):
 # the manager class.
 class SmartCards(object):
 	def __init__(self):	
-		a=1
-		#
+		
+		# key path.
+		if OS in ["linux"]: 
+			self.path = None
+			for path in [
+				"/usr/lib/x86_64-linux-gnu//opensc-pkcs11.so",
+				"/usr/lib/x86_64-linux-gnu//opensc-pkcs11.so",
+				"/usr/lib/arm-linux-gnueabihf/opensc-pkcs11.so",
+				"/usr/local/lib/libykcs11",
+			]:
+				if os.path.exists(path):
+					self.path = path
+					break
+			if self.path == None: raise ValueError("Unable to locate opensc-pkcs11.so path.")
+					
+		elif OS in ["osx"]: 
+			self.path = "/usr/local/lib/libykcs11.dylib"
+
 	def scan(self, silent=False):
 
 		# list.
@@ -86,21 +102,7 @@ class SmartCard(object):
 		self.serial_number = serial_number
 
 		# key path.
-		if OS in ["linux"]: 
-			self.path = None
-			for path in [
-				"/usr/lib/x86_64-linux-gnu//opensc-pkcs11.so",
-				"/usr/lib/x86_64-linux-gnu//opensc-pkcs11.so",
-				"/usr/lib/arm-linux-gnueabihf/opensc-pkcs11.so",
-				"/usr/local/lib/libykcs11",
-			]:
-				if os.path.exists(path):
-					self.path = path
-					break
-			if self.path == None: raise ValueError("Unable to locate opensc-pkcs11.so path.")
-					
-		elif OS in ["osx"]: 
-			self.path = "/usr/local/lib/libykcs11.dylib"
+		self.path = smart_cards.path
 
 		# check permissions.
 		#fp = Formats.FilePath(self.path)
@@ -134,10 +136,11 @@ class SmartCard(object):
 				elif 'pin tries remaining: ' in x:
 					info["pin_attempts"] = x.split("pin tries remaining: ")[1]
 		info["serial_number"] = self.serial_number
-		response["info"] = info
 
 		# success.
-		return r3sponse.success_response(f"Successfully retrieved the information from smart card [{self.serial_number}].")
+		return r3sponse.success_response(f"Successfully retrieved the information from smart card [{self.serial_number}].", {
+				"info":info,
+			})
 
 		#
 	def unblock_pin(self, 
