@@ -551,10 +551,7 @@ class SSH(object):
 		port=22,
 		key_path=None,
 	):
-		base = [
-			#f"SSH_AUTH_SOCK={agent.SSH_AUTH_SOCK}", "&&",
-			#f"SSH_AGENT_PID={agent.SSH_AGENT_PID}", "&&",
-		]
+		base = __create_base__()
 		if alias != None:
 			return base + ['ssh', alias]
 		else:
@@ -587,10 +584,7 @@ class SSHFS(object):
 	):
 
 		# checks.
-		base = [
-			#f"SSH_AUTH_SOCK={agent.SSH_AUTH_SOCK}", "&&",
-			#f"SSH_AGENT_PID={agent.SSH_AGENT_PID}", "&&",
-		]
+		base = __create_base__()
 		if alias == None:
 			success, response = utils.__check_parameters__(empty_value=None, parameters={
 				"username":username,
@@ -601,7 +595,7 @@ class SSHFS(object):
 				"port":port,
 			})
 			if not success: return response
-			base = ["sshfs"]
+			base += ["sshfs"]
 		else:
 			success, response = utils.__check_parameters__(empty_value=None, parameters={
 				"alias":alias,
@@ -609,7 +603,7 @@ class SSHFS(object):
 				"client_path":client_path,
 			})
 			if not success: return response
-			base = ["sshfs", "-p", str(port), "-o", f"IdentityFile={key_path}"]
+			base += ["sshfs", "-p", str(port), "-o", f"IdentityFile={key_path}"]
 			alias = f'{username}@{ip}'
 
 		# do.
@@ -822,11 +816,8 @@ class SCP(object):
 		# option 2:
 		port=22,
 		key_path=None,
-	):
-		base = [
-			#f"SSH_AUTH_SOCK={agent.SSH_AUTH_SOCK}", "&&",
-			#f"SSH_AGENT_PID={agent.SSH_AGENT_PID}", "&&",
-		]
+	):	
+		base = __create_base__()
 		if alias != None:
 			return base + ['ssh', alias]
 		else:
@@ -1082,6 +1073,16 @@ class Agent(object):
 		response["message"] = f"Successfully initialized the ssh agent."
 		return response
 
+def __create_base__():
+	path = "/tmp/shell_source.sh"
+	utils.__save_file__(path, f"SSH_AUTH_SOCK={agent.SSH_AUTH_SOCK}; export SSH_AUTH_SOCK;\nSSH_AGENT_PID={agent.SSH_AGENT_PID}; export SSH_AGENT_PID\n")
+	utils.__set_file_path_permission__(path, permission=755)
+	base = [
+		f"source", path, "&&",
+	]
+	return base
+
+
 # Initialized classes.
 installation = Installation()
 config = Config()
